# DSA-blueprints-modifier
A series of python tools to decode, modify, and reencode Deep Space Airships blueprints

Ever wanted to modify/create programaticaly a blueprint?
Well, now you can with this repo

contributions are welcome
